@@ -1,8 +1,9 @@
 """lime-etl barrel file"""
 from lime_etl.domain import *  # noqa
-from lime_etl.adapters import *  # noqa
-from lime_etl.services import *  # noqa
+from lime_etl.adapter import *  # noqa
+from lime_etl.service import *  # noqa
 from lime_uow.exceptions import *  # noqa
 from lime_uow.unit_of_work import *  # noqa
 from lime_uow.shared_resource_manager import *  # noqa
+from lime_uow.resource import *  # noqa
 from lime_uow.resources import *  # noqa
