@@ -6,6 +6,12 @@ import dataclasses
 from lime_etl.domain import value_objects
 
 
+__all__ = (
+    "JobLogEntryDTO",
+    "JobLogEntry",
+)
+
+
 @dataclasses.dataclass(unsafe_hash=True)
 class JobLogEntryDTO:
     id: str
@@ -46,5 +52,5 @@ class JobLogEntry:
         )
 
     def __str__(self) -> str:
-        ts_str = self.ts.value.strftime('%H:%M:%S')
+        ts_str = self.ts.value.strftime("%H:%M:%S")
         return f"{ts_str} - {self.log_level} - {self.message.value}"
