@@ -18,7 +18,7 @@ __all__ = (
 class JobStatus:
     @staticmethod
     def failed(error_message: str, /) -> JobFailed:
-        msg = value_objects.NonEmptyStr(error_message)
+        msg = value_objects.LogMessage(error_message)
         return JobFailed(msg)
 
     @staticmethod
@@ -27,7 +27,7 @@ class JobStatus:
 
     @staticmethod
     def skipped(reason: str, /) -> JobSkipped:
-        msg = value_objects.NonEmptyStr(reason)
+        msg = value_objects.LogMessage(reason)
         return JobSkipped(reason=msg)
 
     @staticmethod
@@ -37,7 +37,7 @@ class JobStatus:
 
 @dataclasses.dataclass(frozen=True)
 class JobFailed(JobStatus):
-    error_message: value_objects.NonEmptyStr
+    error_message: value_objects.LogMessage
 
 
 @dataclasses.dataclass(frozen=True)
@@ -47,7 +47,7 @@ class JobRanSuccessfully(JobStatus):
 
 @dataclasses.dataclass(frozen=True)
 class JobSkipped(JobStatus):
-    reason: value_objects.NonEmptyStr
+    reason: value_objects.LogMessage
 
 
 @dataclasses.dataclass(frozen=True)
